/* 

FRAM_MB85RC128  read/write library

  E0 = 0
  E1 = 0
  E2 = 0
                          Adr  SAdr   W/R
  Write Adress = 0xA0 = 0b 1010 000    0
  Read Adress  = 0xA1 = 0b 1010 000    1

  E0 = 1
  E1 = 0
  E2 = 0
                           Adr  SAdr   W/R
  Write Adress = 0xA2 = 0b 1010  001    0
  Read Adress  = 0xA3 = 0b 1010  001    1
     
*/


#include "EEPROM_AT24CM02_Lib_header.h"

#define EEPROM_WRITE 0b10101000
#define EEPROM_READ  0b10101001



//--------------- Writes data to AT24CM02 EEPROM - single location
void EEPROM_AT24CM02_WriteByte( unsigned short chipAddr, unsigned int wAddr, unsigned short wData) {

    I2C4_Start();                // issue I2C4 start signal
    I2C4_Write(EEPROM_WRITE | chipAddr);
    I2C4_Write((unsigned char)(wAddr >> 8));
    I2C4_Write((unsigned char)wAddr);
    I2C4_Write(wData);           // send data (data to be written)
    I2C4_Stop();
}

//--------------- Reads data from AT24CM02 EEPROM - single location (random)
unsigned short EEPROM_AT24CM02_ReadByte( unsigned short chipAddr, unsigned int rAddr) {
    unsigned short reslt;

    I2C4_Start();                // issue I2C4 start signal
    I2C4_Write(EEPROM_WRITE | chipAddr);
    I2C4_Write((unsigned char)(rAddr >> 8));
    I2C4_Write((unsigned char)rAddr);
  
    I2C4_Restart();              // issue I2C4 signal repeated start
    I2C4_Write(EEPROM_READ | chipAddr);            // send byte (device address + R)

    reslt = I2C4_Read(1);        // Read the data (NO acknowledge)
    while (!I2C4_Is_Idle())
      asm nop;                   // Wait for the read cycle to finish
    I2C4_Stop();
    return reslt;


}

