/* Project name:
     I2C Example 4 Atmel AT24CM02
 * Copyright:
     Alexander Wolf
 * Revision History:
     - initial release 2016
 * Description:
     Atmel AT24CM02
     262,144  8 bits
     16 Bit Adressing -> 2 Byte Adresse High Byte / Low Byte
     
 * Test configuration:
     MCU:             P32MX795F512L
                      http://ww1.microchip.com/downloads/en/DeviceDoc/61143G.pdf
     Dev.Board:
                      http://www.mikroe.com/eng/products/view/462/lv-32mx-v6-development-system/
     Oscillator:      XT-PLL, 80.000MHz
     Ext. Modules:    On-Board EEPROM 3 Click Module
                      http://www.mikroe.com/click/eeprom3/
     SW:              mikroC PRO for PIC32
                      http://www.mikroe.com/eng/categories/view/89/pic32-compilers/
 * NOTES:
   
   IF YOU USE A Mikroe E EEPROM 3 click in the MIKRO BUS socket CHANGE 
   I2C4 to I2C2 in code!!!
   
   connect I2C4: P32MX795F512L -> RG7 Data Line, RG8 CLK
   Dont forget Pull Up on I2C Lines

   Adressing!
   For:

       A2 = 0
                                Adr  SAdr   W/R
       Write Adress = 0xA0 = 0b 1010 000    0
       Read Adress  = 0xA1 = 0b 1010 000    1


      ( MikroE EEPROM 3 click)
       A2 = 1
                                 Adr  SAdr   W/R
       Write Adress = 0xA8 = 0b 1010  100    0
       Read Adress  = 0xA9 = 0b 1010  100    1

*/

#include "EEPROM_AT24CM02_Lib_header.h"


const int EEPROM_memory_adress = 10; // == 0A ==  00001010  random chosed adress for write process
const unsigned char eepromSlaveAdressMask = 0b00001000;  //  A2 Bit = 1 for Slave adress for mikroe bit

const char writeData[50] = "Hallo World AT24CM02\x00";
char readData[50];


void main() {
  int len = 0, adress_temp_int = 0, i = 0;


  AD1PCFG = 0xFFFF;
  I2C4_Init(100000);
  UART2_Init(115200);
  delay_ms(100);

  UART2_Write_Text("\x0DWriting Single Byte :");
  len = strlen(writeData);
  
  // single Byte Write
  adress_temp_int = EEPROM_memory_adress;
  for( i = 0; i <= len; i++) {
      EEPROM_AT24CM02_WriteByte(eepromSlaveAdressMask, (int) adress_temp_int, writeData[i]);      // writes data, char by char, in the EEPROM
      adress_temp_int++;
      Delay_ms(100);
      Uart2_Write(writeData[i]);
      }
  EEPROM_AT24CM02_WriteByte(eepromSlaveAdressMask, (int) adress_temp_int, 0); // writes string termination
  Uart2_Write_Text("\x0D");
  Delay_ms(20);



  // single Byte Read
  UART2_Write_Text("Reading Single Byte :");
  adress_temp_int = EEPROM_memory_adress;
  for( i = 0; i <= len; i++){
    
      readData[i] = EEPROM_AT24CM02_ReadByte(eepromSlaveAdressMask, adress_temp_int);
      adress_temp_int++;
      Uart2_Write(readData[i]);
      }
  delay_ms(100);
  UART2_Write_Text("\x0D");




  i = strcmp( readData , writeData);
  if( i == 0){
      UART2_Write_Text("FRAM single Byte Write: Test Successful!");
      Uart2_Write_Text("\x0D");
      }
  else{
      UART2_Write_Text("FRAM single Byte Write: Test ERROR!");
      Uart2_Write_Text("\x0D");
      }

  while(1){

      }

}