/* 

EEPROM 24C02 read/write library

  E0 = 0
  E1 = 0
  E2 = 0
                          Adr  SAdr   W/R
  Write Adress = 0xA0 = 0b 1010 000    0
  Read Adress  = 0xA1 = 0b 1010 000    1

  E0 = 1
  E1 = 0
  E2 = 0
                           Adr  SAdr   W/R
  Write Adress = 0xA2 = 0b 1010  001    0
  Read Adress  = 0xA3 = 0b 1010  001    1
     
*/


#include "EEPROM_M24C02_Lib_header.h"

#define EEPROM_WRITE 0b10100000
#define EEPROM_READ  0b10100001



//--------------- Writes data to 24C02 EEPROM - single location
void EEPROM_24C02_WriteByte( unsigned short chipAddr, unsigned short wAddr, unsigned short wData) {

    I2C4_Start();                // issue I2C4 start signal
    I2C4_Write(EEPROM_WRITE | chipAddr);
    I2C4_Write(wAddr);           // send byte (address of EEPROM location)
    I2C4_Write(wData);           // send data (data to be written)
    I2C4_Stop();
}

//--------------- Reads data from 24C02 EEPROM - single location (random)
unsigned short EEPROM_24C02_ReadByte( unsigned short chipAddr, unsigned short rAddr) {
    unsigned short reslt;
    unsigned char test_ =  EEPROM_WRITE | chipAddr;

    I2C4_Start();                // issue I2C4 start signal
    I2C4_Write(EEPROM_READ | chipAddr);
    I2C4_Write(rAddr);           // send byte (data address)
    I2C4_Restart();              // issue I2C4 signal repeated start
    I2C4_Write(EEPROM_READ | chipAddr);            // send byte (device address + R)

    reslt = I2C4_Read(1);        // Read the data (NO acknowledge)
    while (!I2C4_Is_Idle())
      asm nop;                   // Wait for the read cycle to finish
    I2C4_Stop();
    return reslt;
}

//--------------- Writes String into EEEPROM, string should be null terminated
void EEPROM_24C02_WriteString( unsigned short chipAddr, unsigned short wAddr, char* wData) {
  char i,tmp;
  i=0;
  while(wData[i]!=0){
     EEPROM_24C02_WriteByte(chipAddr, wAddr++,wData[i++]);
  }
  EEPROM_24C02_WriteByte(chipAddr ,wAddr,0);
}

//---------------Read string from EEPROM
void EEPROM_24C02_ReadString(unsigned short chipAddr, unsigned short rAddr, char* rData) {
  char tmp,i;
  i=0;
  tmp = 255;
  while(tmp!=0){
    tmp = EEPROM_24C02_ReadByte(chipAddr ,rAddr++);
    rData[i++]=tmp;
  }
}

//--------------- Reads data from 24C02 EEPROM - sequential read
void EEPROM_24C02_ReadSeq( unsigned short chipAddr,
                           unsigned short rAddr,
                           unsigned char  *rdData,
                           unsigned short rLen) {
  unsigned short i;
  I2C4_Start();                  // issue I2C4 start signal
  I2C4_Write(EEPROM_WRITE | chipAddr);
  I2C4_Write(rAddr);             // send byte (address of EEPROM location)
  I2C4_Restart();                // issue I2C4 signal repeated start
  I2C4_Write(EEPROM_READ | chipAddr);   // send byte (device address + R)
  i = 0;
  while (i < rLen) {
    rdData[i] = I2C4_Read(0);    // read data (acknowledge)
    Delay_ms(20);
    i++ ;
  }
  rdData[i] = I2C4_Read(1);      // last data is read (no acknowledge)
  I2C4_Stop();
}